# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/video/video.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.validate import validate_pb2 as validate_dot_validate__pb2
from sensory_cloud.generated.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='v1/video/video.proto',
  package='sensory.api.v1.video',
  syntax='proto3',
  serialized_options=b'\n\034ai.sensorycloud.api.v1.videoB\026SensoryApiV1VideoProtoP\001Z:gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/video',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14v1/video/video.proto\x12\x14sensory.api.v1.video\x1a\x17validate/validate.proto\x1a\x13\x63ommon/common.proto\"\xde\x01\n\nVideoModel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cisEnrollable\x18\x02 \x01(\x08\x12\x30\n\tmodelType\x18\x03 \x01(\x0e\x32\x1d.sensory.api.common.ModelType\x12\x13\n\x0b\x66ixedObject\x18\x04 \x01(\t\x12\x10\n\x08versions\x18\x05 \x03(\t\x12\x36\n\ntechnology\x18\x06 \x01(\x0e\x32\".sensory.api.common.TechnologyType\x12\x1b\n\x13isLivenessSupported\x18\x07 \x01(\x08\"\x12\n\x10GetModelsRequest\"E\n\x11GetModelsResponse\x12\x30\n\x06models\x18\x01 \x03(\x0b\x32 .sensory.api.v1.video.VideoModel\"\x8a\x01\n\x17\x43reateEnrollmentRequest\x12>\n\x06\x63onfig\x18\x01 \x01(\x0b\x32,.sensory.api.v1.video.CreateEnrollmentConfigH\x00\x12\x16\n\x0cimageContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\x82\x01\n\x13\x41uthenticateRequest\x12:\n\x06\x63onfig\x18\x01 \x01(\x0b\x32(.sensory.api.v1.video.AuthenticateConfigH\x00\x12\x16\n\x0cimageContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\x90\x01\n\x1aValidateRecognitionRequest\x12\x41\n\x06\x63onfig\x18\x01 \x01(\x0b\x32/.sensory.api.v1.video.ValidateRecognitionConfigH\x00\x12\x16\n\x0cimageContent\x18\x02 \x01(\x0cH\x00\x42\x17\n\x10streamingRequest\x12\x03\xf8\x42\x01\"\xd0\x01\n\x18\x43reateEnrollmentResponse\x12\x17\n\x0fpercentComplete\x18\x01 \x01(\x03\x12\x0f\n\x07isAlive\x18\x02 \x01(\x08\x12\x14\n\x0c\x65nrollmentId\x18\x03 \x01(\t\x12\x11\n\tmodelName\x18\x04 \x01(\t\x12\x14\n\x0cmodelVersion\x18\x05 \x01(\t\x12\r\n\x05score\x18\x06 \x01(\x02\x12<\n\x0f\x65nrollmentToken\x18\x07 \x01(\x0b\x32#.sensory.api.common.EnrollmentToken\"\x9f\x01\n\x14\x41uthenticateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05score\x18\x02 \x01(\x02\x12\x0f\n\x07isAlive\x18\x03 \x01(\x08\x12\x30\n\x05token\x18\x04 \x01(\x0b\x32!.sensory.api.common.TokenResponse\x12\x0e\n\x06userId\x18\x05 \x01(\t\x12\x14\n\x0c\x65nrollmentId\x18\x06 \x01(\t\"=\n\x1bLivenessRecognitionResponse\x12\x0f\n\x07isAlive\x18\x01 \x01(\x08\x12\r\n\x05score\x18\x02 \x01(\x02\"\xae\x03\n\x16\x43reateEnrollmentConfig\x12\x19\n\x06userId\x18\x01 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1b\n\x08\x64\x65viceId\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12\x1d\n\tmodelName\x18\x03 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x1d\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x18\xff\x07\x12\x19\n\x11isLivenessEnabled\x18\x05 \x01(\x08\x12O\n\x11livenessThreshold\x18\x06 \x01(\x0e\x32*.sensory.api.v1.video.RecognitionThresholdB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x41\n\x0b\x63ompression\x18\x07 \x01(\x0b\x32,.sensory.api.common.CompressionConfiguration\x12\x1c\n\x0breferenceId\x18\x08 \x01(\tB\x07\xfa\x42\x04r\x02\x18\x7f\x12!\n\x19numLivenessFramesRequired\x18\t \x01(\x05\x12.\n&disableServerEnrollmentTemplateStorage\x18\n \x01(\x08\"\xc2\x02\n\x12\x41uthenticateConfig\x12 \n\x0c\x65nrollmentId\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x12\x1b\n\x11\x65nrollmentGroupId\x18\x02 \x01(\tH\x00\x12\x19\n\x11isLivenessEnabled\x18\x03 \x01(\x08\x12O\n\x11livenessThreshold\x18\x04 \x01(\x0e\x32*.sensory.api.v1.video.RecognitionThresholdB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x41\n\x0b\x63ompression\x18\x05 \x01(\x0b\x32,.sensory.api.common.CompressionConfiguration\x12\x16\n\x0e\x64oIncludeToken\x18\x06 \x01(\x08\x12\x17\n\x0f\x65nrollmentToken\x18\x07 \x01(\x0c\x42\r\n\x06\x61uthId\x12\x03\xf8\x42\x01\"\x9e\x01\n\x19ValidateRecognitionConfig\x12\x1d\n\tmodelName\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x12\x19\n\x06userId\x18\x02 \x01(\tB\t\xfa\x42\x06r\x04\x10\x01\x18\x7f\x12G\n\tthreshold\x18\x03 \x01(\x0e\x32*.sensory.api.v1.video.RecognitionThresholdB\x08\xfa\x42\x05\x82\x01\x02\x10\x01*B\n\x14RecognitionThreshold\x12\x07\n\x03LOW\x10\x00\x12\n\n\x06MEDIUM\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\x0b\n\x07HIGHEST\x10\x03\x32m\n\x0bVideoModels\x12^\n\tGetModels\x12&.sensory.api.v1.video.GetModelsRequest\x1a\'.sensory.api.v1.video.GetModelsResponse\"\x00\x32\xf7\x01\n\x0fVideoBiometrics\x12w\n\x10\x43reateEnrollment\x12-.sensory.api.v1.video.CreateEnrollmentRequest\x1a..sensory.api.v1.video.CreateEnrollmentResponse\"\x00(\x01\x30\x01\x12k\n\x0c\x41uthenticate\x12).sensory.api.v1.video.AuthenticateRequest\x1a*.sensory.api.v1.video.AuthenticateResponse\"\x00(\x01\x30\x01\x32\x91\x01\n\x10VideoRecognition\x12}\n\x10ValidateLiveness\x12\x30.sensory.api.v1.video.ValidateRecognitionRequest\x1a\x31.sensory.api.v1.video.LivenessRecognitionResponse\"\x00(\x01\x30\x01\x42t\n\x1c\x61i.sensorycloud.api.v1.videoB\x16SensoryApiV1VideoProtoP\x01Z:gitlab.com/sensory-cloud/server/titan.git/pkg/api/v1/videob\x06proto3'
  ,
  dependencies=[validate_dot_validate__pb2.DESCRIPTOR,common_dot_common__pb2.DESCRIPTOR,])

_RECOGNITIONTHRESHOLD = _descriptor.EnumDescriptor(
  name='RecognitionThreshold',
  full_name='sensory.api.v1.video.RecognitionThreshold',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHEST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2184,
  serialized_end=2250,
)
_sym_db.RegisterEnumDescriptor(_RECOGNITIONTHRESHOLD)

RecognitionThreshold = enum_type_wrapper.EnumTypeWrapper(_RECOGNITIONTHRESHOLD)
LOW = 0
MEDIUM = 1
HIGH = 2
HIGHEST = 3



_VIDEOMODEL = _descriptor.Descriptor(
  name='VideoModel',
  full_name='sensory.api.v1.video.VideoModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='sensory.api.v1.video.VideoModel.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isEnrollable', full_name='sensory.api.v1.video.VideoModel.isEnrollable', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelType', full_name='sensory.api.v1.video.VideoModel.modelType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixedObject', full_name='sensory.api.v1.video.VideoModel.fixedObject', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versions', full_name='sensory.api.v1.video.VideoModel.versions', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='technology', full_name='sensory.api.v1.video.VideoModel.technology', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLivenessSupported', full_name='sensory.api.v1.video.VideoModel.isLivenessSupported', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=315,
)


_GETMODELSREQUEST = _descriptor.Descriptor(
  name='GetModelsRequest',
  full_name='sensory.api.v1.video.GetModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=335,
)


_GETMODELSRESPONSE = _descriptor.Descriptor(
  name='GetModelsResponse',
  full_name='sensory.api.v1.video.GetModelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='models', full_name='sensory.api.v1.video.GetModelsResponse.models', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=406,
)


_CREATEENROLLMENTREQUEST = _descriptor.Descriptor(
  name='CreateEnrollmentRequest',
  full_name='sensory.api.v1.video.CreateEnrollmentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.video.CreateEnrollmentRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imageContent', full_name='sensory.api.v1.video.CreateEnrollmentRequest.imageContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.video.CreateEnrollmentRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=409,
  serialized_end=547,
)


_AUTHENTICATEREQUEST = _descriptor.Descriptor(
  name='AuthenticateRequest',
  full_name='sensory.api.v1.video.AuthenticateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.video.AuthenticateRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imageContent', full_name='sensory.api.v1.video.AuthenticateRequest.imageContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.video.AuthenticateRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=550,
  serialized_end=680,
)


_VALIDATERECOGNITIONREQUEST = _descriptor.Descriptor(
  name='ValidateRecognitionRequest',
  full_name='sensory.api.v1.video.ValidateRecognitionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='sensory.api.v1.video.ValidateRecognitionRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imageContent', full_name='sensory.api.v1.video.ValidateRecognitionRequest.imageContent', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streamingRequest', full_name='sensory.api.v1.video.ValidateRecognitionRequest.streamingRequest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=683,
  serialized_end=827,
)


_CREATEENROLLMENTRESPONSE = _descriptor.Descriptor(
  name='CreateEnrollmentResponse',
  full_name='sensory.api.v1.video.CreateEnrollmentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percentComplete', full_name='sensory.api.v1.video.CreateEnrollmentResponse.percentComplete', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isAlive', full_name='sensory.api.v1.video.CreateEnrollmentResponse.isAlive', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.video.CreateEnrollmentResponse.enrollmentId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.video.CreateEnrollmentResponse.modelName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelVersion', full_name='sensory.api.v1.video.CreateEnrollmentResponse.modelVersion', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='sensory.api.v1.video.CreateEnrollmentResponse.score', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentToken', full_name='sensory.api.v1.video.CreateEnrollmentResponse.enrollmentToken', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=1038,
)


_AUTHENTICATERESPONSE = _descriptor.Descriptor(
  name='AuthenticateResponse',
  full_name='sensory.api.v1.video.AuthenticateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='sensory.api.v1.video.AuthenticateResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='sensory.api.v1.video.AuthenticateResponse.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isAlive', full_name='sensory.api.v1.video.AuthenticateResponse.isAlive', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='sensory.api.v1.video.AuthenticateResponse.token', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.video.AuthenticateResponse.userId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.video.AuthenticateResponse.enrollmentId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1200,
)


_LIVENESSRECOGNITIONRESPONSE = _descriptor.Descriptor(
  name='LivenessRecognitionResponse',
  full_name='sensory.api.v1.video.LivenessRecognitionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='isAlive', full_name='sensory.api.v1.video.LivenessRecognitionResponse.isAlive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='sensory.api.v1.video.LivenessRecognitionResponse.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1263,
)


_CREATEENROLLMENTCONFIG = _descriptor.Descriptor(
  name='CreateEnrollmentConfig',
  full_name='sensory.api.v1.video.CreateEnrollmentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.video.CreateEnrollmentConfig.userId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='sensory.api.v1.video.CreateEnrollmentConfig.deviceId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.video.CreateEnrollmentConfig.modelName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='sensory.api.v1.video.CreateEnrollmentConfig.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\030\377\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLivenessEnabled', full_name='sensory.api.v1.video.CreateEnrollmentConfig.isLivenessEnabled', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='livenessThreshold', full_name='sensory.api.v1.video.CreateEnrollmentConfig.livenessThreshold', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='sensory.api.v1.video.CreateEnrollmentConfig.compression', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='referenceId', full_name='sensory.api.v1.video.CreateEnrollmentConfig.referenceId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numLivenessFramesRequired', full_name='sensory.api.v1.video.CreateEnrollmentConfig.numLivenessFramesRequired', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disableServerEnrollmentTemplateStorage', full_name='sensory.api.v1.video.CreateEnrollmentConfig.disableServerEnrollmentTemplateStorage', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1696,
)


_AUTHENTICATECONFIG = _descriptor.Descriptor(
  name='AuthenticateConfig',
  full_name='sensory.api.v1.video.AuthenticateConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enrollmentId', full_name='sensory.api.v1.video.AuthenticateConfig.enrollmentId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005r\003\260\001\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentGroupId', full_name='sensory.api.v1.video.AuthenticateConfig.enrollmentGroupId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLivenessEnabled', full_name='sensory.api.v1.video.AuthenticateConfig.isLivenessEnabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='livenessThreshold', full_name='sensory.api.v1.video.AuthenticateConfig.livenessThreshold', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='sensory.api.v1.video.AuthenticateConfig.compression', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doIncludeToken', full_name='sensory.api.v1.video.AuthenticateConfig.doIncludeToken', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enrollmentToken', full_name='sensory.api.v1.video.AuthenticateConfig.enrollmentToken', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='authId', full_name='sensory.api.v1.video.AuthenticateConfig.authId',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1699,
  serialized_end=2021,
)


_VALIDATERECOGNITIONCONFIG = _descriptor.Descriptor(
  name='ValidateRecognitionConfig',
  full_name='sensory.api.v1.video.ValidateRecognitionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modelName', full_name='sensory.api.v1.video.ValidateRecognitionConfig.modelName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007r\005\020\001\030\377\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='sensory.api.v1.video.ValidateRecognitionConfig.userId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006r\004\020\001\030\177', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='sensory.api.v1.video.ValidateRecognitionConfig.threshold', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2024,
  serialized_end=2182,
)

_VIDEOMODEL.fields_by_name['modelType'].enum_type = common_dot_common__pb2._MODELTYPE
_VIDEOMODEL.fields_by_name['technology'].enum_type = common_dot_common__pb2._TECHNOLOGYTYPE
_GETMODELSRESPONSE.fields_by_name['models'].message_type = _VIDEOMODEL
_CREATEENROLLMENTREQUEST.fields_by_name['config'].message_type = _CREATEENROLLMENTCONFIG
_CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _CREATEENROLLMENTREQUEST.fields_by_name['config'])
_CREATEENROLLMENTREQUEST.fields_by_name['config'].containing_oneof = _CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest']
_CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _CREATEENROLLMENTREQUEST.fields_by_name['imageContent'])
_CREATEENROLLMENTREQUEST.fields_by_name['imageContent'].containing_oneof = _CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest']
_AUTHENTICATEREQUEST.fields_by_name['config'].message_type = _AUTHENTICATECONFIG
_AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _AUTHENTICATEREQUEST.fields_by_name['config'])
_AUTHENTICATEREQUEST.fields_by_name['config'].containing_oneof = _AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest']
_AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _AUTHENTICATEREQUEST.fields_by_name['imageContent'])
_AUTHENTICATEREQUEST.fields_by_name['imageContent'].containing_oneof = _AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest']
_VALIDATERECOGNITIONREQUEST.fields_by_name['config'].message_type = _VALIDATERECOGNITIONCONFIG
_VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _VALIDATERECOGNITIONREQUEST.fields_by_name['config'])
_VALIDATERECOGNITIONREQUEST.fields_by_name['config'].containing_oneof = _VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest']
_VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest'].fields.append(
  _VALIDATERECOGNITIONREQUEST.fields_by_name['imageContent'])
_VALIDATERECOGNITIONREQUEST.fields_by_name['imageContent'].containing_oneof = _VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest']
_CREATEENROLLMENTRESPONSE.fields_by_name['enrollmentToken'].message_type = common_dot_common__pb2._ENROLLMENTTOKEN
_AUTHENTICATERESPONSE.fields_by_name['token'].message_type = common_dot_common__pb2._TOKENRESPONSE
_CREATEENROLLMENTCONFIG.fields_by_name['livenessThreshold'].enum_type = _RECOGNITIONTHRESHOLD
_CREATEENROLLMENTCONFIG.fields_by_name['compression'].message_type = common_dot_common__pb2._COMPRESSIONCONFIGURATION
_AUTHENTICATECONFIG.fields_by_name['livenessThreshold'].enum_type = _RECOGNITIONTHRESHOLD
_AUTHENTICATECONFIG.fields_by_name['compression'].message_type = common_dot_common__pb2._COMPRESSIONCONFIGURATION
_AUTHENTICATECONFIG.oneofs_by_name['authId'].fields.append(
  _AUTHENTICATECONFIG.fields_by_name['enrollmentId'])
_AUTHENTICATECONFIG.fields_by_name['enrollmentId'].containing_oneof = _AUTHENTICATECONFIG.oneofs_by_name['authId']
_AUTHENTICATECONFIG.oneofs_by_name['authId'].fields.append(
  _AUTHENTICATECONFIG.fields_by_name['enrollmentGroupId'])
_AUTHENTICATECONFIG.fields_by_name['enrollmentGroupId'].containing_oneof = _AUTHENTICATECONFIG.oneofs_by_name['authId']
_VALIDATERECOGNITIONCONFIG.fields_by_name['threshold'].enum_type = _RECOGNITIONTHRESHOLD
DESCRIPTOR.message_types_by_name['VideoModel'] = _VIDEOMODEL
DESCRIPTOR.message_types_by_name['GetModelsRequest'] = _GETMODELSREQUEST
DESCRIPTOR.message_types_by_name['GetModelsResponse'] = _GETMODELSRESPONSE
DESCRIPTOR.message_types_by_name['CreateEnrollmentRequest'] = _CREATEENROLLMENTREQUEST
DESCRIPTOR.message_types_by_name['AuthenticateRequest'] = _AUTHENTICATEREQUEST
DESCRIPTOR.message_types_by_name['ValidateRecognitionRequest'] = _VALIDATERECOGNITIONREQUEST
DESCRIPTOR.message_types_by_name['CreateEnrollmentResponse'] = _CREATEENROLLMENTRESPONSE
DESCRIPTOR.message_types_by_name['AuthenticateResponse'] = _AUTHENTICATERESPONSE
DESCRIPTOR.message_types_by_name['LivenessRecognitionResponse'] = _LIVENESSRECOGNITIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateEnrollmentConfig'] = _CREATEENROLLMENTCONFIG
DESCRIPTOR.message_types_by_name['AuthenticateConfig'] = _AUTHENTICATECONFIG
DESCRIPTOR.message_types_by_name['ValidateRecognitionConfig'] = _VALIDATERECOGNITIONCONFIG
DESCRIPTOR.enum_types_by_name['RecognitionThreshold'] = _RECOGNITIONTHRESHOLD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VideoModel = _reflection.GeneratedProtocolMessageType('VideoModel', (_message.Message,), {
  'DESCRIPTOR' : _VIDEOMODEL,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.VideoModel)
  })
_sym_db.RegisterMessage(VideoModel)

GetModelsRequest = _reflection.GeneratedProtocolMessageType('GetModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELSREQUEST,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.GetModelsRequest)
  })
_sym_db.RegisterMessage(GetModelsRequest)

GetModelsResponse = _reflection.GeneratedProtocolMessageType('GetModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELSRESPONSE,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.GetModelsResponse)
  })
_sym_db.RegisterMessage(GetModelsResponse)

CreateEnrollmentRequest = _reflection.GeneratedProtocolMessageType('CreateEnrollmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTREQUEST,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.CreateEnrollmentRequest)
  })
_sym_db.RegisterMessage(CreateEnrollmentRequest)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

ValidateRecognitionRequest = _reflection.GeneratedProtocolMessageType('ValidateRecognitionRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATERECOGNITIONREQUEST,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.ValidateRecognitionRequest)
  })
_sym_db.RegisterMessage(ValidateRecognitionRequest)

CreateEnrollmentResponse = _reflection.GeneratedProtocolMessageType('CreateEnrollmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTRESPONSE,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.CreateEnrollmentResponse)
  })
_sym_db.RegisterMessage(CreateEnrollmentResponse)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

LivenessRecognitionResponse = _reflection.GeneratedProtocolMessageType('LivenessRecognitionResponse', (_message.Message,), {
  'DESCRIPTOR' : _LIVENESSRECOGNITIONRESPONSE,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.LivenessRecognitionResponse)
  })
_sym_db.RegisterMessage(LivenessRecognitionResponse)

CreateEnrollmentConfig = _reflection.GeneratedProtocolMessageType('CreateEnrollmentConfig', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENROLLMENTCONFIG,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.CreateEnrollmentConfig)
  })
_sym_db.RegisterMessage(CreateEnrollmentConfig)

AuthenticateConfig = _reflection.GeneratedProtocolMessageType('AuthenticateConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATECONFIG,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.AuthenticateConfig)
  })
_sym_db.RegisterMessage(AuthenticateConfig)

ValidateRecognitionConfig = _reflection.GeneratedProtocolMessageType('ValidateRecognitionConfig', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATERECOGNITIONCONFIG,
  '__module__' : 'v1.video.video_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.v1.video.ValidateRecognitionConfig)
  })
_sym_db.RegisterMessage(ValidateRecognitionConfig)


DESCRIPTOR._options = None
_CREATEENROLLMENTREQUEST.oneofs_by_name['streamingRequest']._options = None
_AUTHENTICATEREQUEST.oneofs_by_name['streamingRequest']._options = None
_VALIDATERECOGNITIONREQUEST.oneofs_by_name['streamingRequest']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['userId']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['deviceId']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['modelName']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['description']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['livenessThreshold']._options = None
_CREATEENROLLMENTCONFIG.fields_by_name['referenceId']._options = None
_AUTHENTICATECONFIG.oneofs_by_name['authId']._options = None
_AUTHENTICATECONFIG.fields_by_name['enrollmentId']._options = None
_AUTHENTICATECONFIG.fields_by_name['livenessThreshold']._options = None
_VALIDATERECOGNITIONCONFIG.fields_by_name['modelName']._options = None
_VALIDATERECOGNITIONCONFIG.fields_by_name['userId']._options = None
_VALIDATERECOGNITIONCONFIG.fields_by_name['threshold']._options = None

_VIDEOMODELS = _descriptor.ServiceDescriptor(
  name='VideoModels',
  full_name='sensory.api.v1.video.VideoModels',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2252,
  serialized_end=2361,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetModels',
    full_name='sensory.api.v1.video.VideoModels.GetModels',
    index=0,
    containing_service=None,
    input_type=_GETMODELSREQUEST,
    output_type=_GETMODELSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIDEOMODELS)

DESCRIPTOR.services_by_name['VideoModels'] = _VIDEOMODELS


_VIDEOBIOMETRICS = _descriptor.ServiceDescriptor(
  name='VideoBiometrics',
  full_name='sensory.api.v1.video.VideoBiometrics',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2364,
  serialized_end=2611,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateEnrollment',
    full_name='sensory.api.v1.video.VideoBiometrics.CreateEnrollment',
    index=0,
    containing_service=None,
    input_type=_CREATEENROLLMENTREQUEST,
    output_type=_CREATEENROLLMENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Authenticate',
    full_name='sensory.api.v1.video.VideoBiometrics.Authenticate',
    index=1,
    containing_service=None,
    input_type=_AUTHENTICATEREQUEST,
    output_type=_AUTHENTICATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIDEOBIOMETRICS)

DESCRIPTOR.services_by_name['VideoBiometrics'] = _VIDEOBIOMETRICS


_VIDEORECOGNITION = _descriptor.ServiceDescriptor(
  name='VideoRecognition',
  full_name='sensory.api.v1.video.VideoRecognition',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2614,
  serialized_end=2759,
  methods=[
  _descriptor.MethodDescriptor(
    name='ValidateLiveness',
    full_name='sensory.api.v1.video.VideoRecognition.ValidateLiveness',
    index=0,
    containing_service=None,
    input_type=_VALIDATERECOGNITIONREQUEST,
    output_type=_LIVENESSRECOGNITIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIDEORECOGNITION)

DESCRIPTOR.services_by_name['VideoRecognition'] = _VIDEORECOGNITION

# @@protoc_insertion_point(module_scope)



from sensory_cloud.config import Config

import sensory_cloud.generated.health.health_pb2_grpc as health_pb2_grpc
import sensory_cloud.generated.health.health_pb2 as health_pb2
import sensory_cloud.generated.common.common_pb2 as common_pb2


class HealthService:
    """
    Class used to obtain health status of Sensory Cloud
    """

    def __init__(self, config: Config):
        """
        Constructor method for the HealthService class

        Arguments:
            config: Config object containing the relevant grpc connection information
        """

        self._config: Config = config
        self._health_client: health_pb2_grpc.HealthServiceStub = (
            health_pb2_grpc.HealthServiceStub(channel=config.channel)
        )

    def get_health(self) -> common_pb2.ServerHealthResponse:
        """
        Method that gets the health status of the cloud endpoint defined in the Config object
        set upon construction

        Returns:
            A ServerHealthResponse object
        """

        health_request = health_pb2.HealthRequest()
        server_health_response: common_pb2.ServerHealthResponse = (
            self._health_client.GetHealth(request=health_request)
        )

        return server_health_response



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: health/health.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from sensory_cloud.generated.common import common_pb2 as common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='health/health.proto',
  package='sensory.api.health',
  syntax='proto3',
  serialized_options=b'\n\032ai.sensorycloud.api.healthB\025SensoryApiHealthProtoP\001Z8gitlab.com/sensory-cloud/server/titan.git/pkg/api/health',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13health/health.proto\x12\x12sensory.api.health\x1a\x13\x63ommon/common.proto\"\x0f\n\rHealthRequest2k\n\rHealthService\x12Z\n\tGetHealth\x12!.sensory.api.health.HealthRequest\x1a(.sensory.api.common.ServerHealthResponse\"\x00\x42o\n\x1a\x61i.sensorycloud.api.healthB\x15SensoryApiHealthProtoP\x01Z8gitlab.com/sensory-cloud/server/titan.git/pkg/api/healthb\x06proto3'
  ,
  dependencies=[common_dot_common__pb2.DESCRIPTOR,])




_HEALTHREQUEST = _descriptor.Descriptor(
  name='HealthRequest',
  full_name='sensory.api.health.HealthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=79,
)

DESCRIPTOR.message_types_by_name['HealthRequest'] = _HEALTHREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthRequest = _reflection.GeneratedProtocolMessageType('HealthRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHREQUEST,
  '__module__' : 'health.health_pb2'
  # @@protoc_insertion_point(class_scope:sensory.api.health.HealthRequest)
  })
_sym_db.RegisterMessage(HealthRequest)


DESCRIPTOR._options = None

_HEALTHSERVICE = _descriptor.ServiceDescriptor(
  name='HealthService',
  full_name='sensory.api.health.HealthService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=81,
  serialized_end=188,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetHealth',
    full_name='sensory.api.health.HealthService.GetHealth',
    index=0,
    containing_service=None,
    input_type=_HEALTHREQUEST,
    output_type=common_dot_common__pb2._SERVERHEALTHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HEALTHSERVICE)

DESCRIPTOR.services_by_name['HealthService'] = _HEALTHSERVICE

# @@protoc_insertion_point(module_scope)



import unittest
from unittest.mock import MagicMock

from sensory_cloud.config import Config, CloudHost
from sensory_cloud.token_manager import ITokenManager, TokenManager
from sensory_cloud.services.oauth_service import ISecureCredentialStore, OauthService
from sensory_cloud.services.audio_service import AudioService
from sensory_cloud.generated.v1.audio.audio_pb2 import (
    AudioConfig,
    AudioModel,
    AuthenticateConfig,
    AuthenticateRequest,
    AuthenticateResponse,
    CreateEnrolledEventRequest,
    CreateEnrollmentConfig,
    CreateEnrollmentRequest,
    CreateEnrollmentResponse,
    GetModelsResponse,
    ThresholdSensitivity,
    TranscribeConfig,
    TranscribeRequest,
    TranscribeResponse,
    ValidateEnrolledEventConfig,
    ValidateEnrolledEventRequest,
    ValidateEnrolledEventResponse,
    ValidateEventConfig,
    ValidateEventRequest,
    ValidateEventResponse,
    CreateEnrollmentEventConfig,
)
from sensory_cloud.generated.v1.audio.audio_pb2_grpc import (
    AudioModelsStub,
    AudioBiometricsStub,
    AudioEventsStub,
    AudioTranscriptionsStub,
)


class MockCredentialStore(ISecureCredentialStore):
    def __init__(self, client_id, client_secret):
        self._client_id = client_id
        self._client_secret = client_secret

    @property
    def client_id(self):
        return self._client_id

    @property
    def client_secret(self):
        return self._client_secret


class MockAudioService(AudioService):
    def __init__(
        self,
        config: Config,
        token_manager: ITokenManager,
        audio_models_client: AudioModelsStub,
        audio_biometrics_client: AudioBiometricsStub,
        audio_events_client: AudioEventsStub,
        audio_transcriptions_client: AudioTranscriptionsStub,
    ):
        self.config: Config = config
        self._token_manager: ITokenManager = token_manager
        self._audio_models_client: AudioModelsStub = audio_models_client
        self._audio_biometrics_client: AudioBiometricsStub = audio_biometrics_client
        self._audio_events_client: AudioEventsStub = audio_events_client
        self._audio_transcriptions_client: AudioTranscriptionsStub = (
            audio_transcriptions_client
        )


class AudioServiceTest(unittest.TestCase):
    cloud_host: CloudHost = CloudHost(host="domain.name")
    config: Config = Config(cloud_host=cloud_host, tenant_id="tenant-id")
    config.connect()

    credential_store: MockCredentialStore = MockCredentialStore(
        client_id="client-id", client_secret="client-secret"
    )
    oauth_service: OauthService = OauthService(
        config=config, secure_credential_store=credential_store
    )
    token_manager: TokenManager = TokenManager(oauth_service=oauth_service)
    token_manager.get_authorization_metadata = MagicMock(return_value=None)

    audio_models_client: AudioModelsStub = AudioModelsStub(config.channel)
    audio_biometrics_client: AudioBiometricsStub = AudioBiometricsStub(config.channel)
    audio_events_client: AudioEventsStub = AudioEventsStub(config.channel)
    audio_transcriptions_client: AudioTranscriptionsStub = AudioTranscriptionsStub(
        config.channel
    )

    audio_config: AudioConfig = AudioConfig(
        encoding=AudioConfig.AudioEncoding.Value("LINEAR16"),
        audioChannelCount=1,
        sampleRateHertz=16000,
        languageCode="en-US",
    )

    def test_get_models(self):
        self.config.connect()

        response: GetModelsResponse = GetModelsResponse(
            models=[AudioModel(name="model-name")]
        )
        self.audio_models_client.GetModels = MagicMock(return_value=response)

        audio_service: MockAudioService = MockAudioService(
            config=self.config,
            token_manager=self.token_manager,
            audio_models_client=self.audio_models_client,
            audio_biometrics_client=self.audio_biometrics_client,
            audio_events_client=self.audio_events_client,
            audio_transcriptions_client=self.audio_transcriptions_client,
        )

        models_response: GetModelsResponse = audio_service.get_models()

        self.assertEqual(models_response, response)

        self.config.channel.close()

    def test_stream_enrollment(self):
        self.config.connect()

        description: str = "my-description"
        user_id: str = "user-id"
        device_id: str = "device-id"
        model_name: str = "my-model"
        is_liveness_enabled: bool = False

        enrollment_config: CreateEnrollmentConfig = CreateEnrollmentConfig(
            audio=self.audio_config,
            description=description,
            userId=user_id,
            modelName=model_name,
            deviceId=device_id,
            isLivenessEnabled=is_liveness_enabled,
        )

        mock_request = CreateEnrollmentRequest(config=enrollment_config)
        mock_response = CreateEnrollmentResponse()
        self.audio_biometrics_client.CreateEnrollment = MagicMock(
            return_value=(mock_request, mock_response)
        )

        audio_service: MockAudioService = MockAudioService(
            config=self.config,
            token_manager=self.token_manager,
            audio_models_client=self.audio_models_client,
            audio_biometrics_client=self.audio_biometrics_client,
            audio_events_client=self.audio_events_client,
            audio_transcriptions_client=self.audio_transcriptions_client,
        )

        (
            enrollment_stream_request,
            enrollment_stream_response,
        ) = audio_service.stream_enrollment(
            audio_config=self.audio_config,
            description=description,
            user_id=user_id,
            device_id=device_id,
            model_name=model_name,
            is_liveness_enabled=is_liveness_enabled,
            audio_stream_iterator=None,
        )

        self.assertIsNotNone(enrollment_stream_response)

        config_message = enrollment_stream_request.config

        self.assertEqual(
            config_message.audio,
            self.audio_config,
            "Audio config should match what was passed in",
        )
        self.assertEqual(
            config_message.description,
            description,
            "Description should match what was passed in",
        )
        self.assertEqual(
            config_message.userId, user_id, "User ID should match what was passed in"
        )
        self.assertEqual(
            config_message.modelName,
            model_name,
            "Model name should match what was passed in",
        )
        self.assertEqual(
            config_message.isLivenessEnabled,
            is_liveness_enabled,
            "Is liveness enabled should match what was passed in",
        )

        self.config.channel.close()

    def test_stream_authentication(self):
        self.config.connect()

        enrollment_id: str = "enrollment-id"
        is_liveness_enabled: bool = False

        sensitivity: ThresholdSensitivity = ThresholdSensitivity.Value("LOW")
        security: AuthenticateConfig.ThresholdSecurity = (
            AuthenticateConfig.ThresholdSecurity.Value("LOW")
        )
        authenticate_config: AuthenticateConfig = AuthenticateConfig(
            audio=self.audio_config,
            enrollmentId=enrollment_id,
            sensitivity=sensitivity,
            security=security,
            isLivenessEnabled=is_liveness_enabled,
        )

        mock_request: AuthenticateRequest = AuthenticateRequest(
            config=authenticate_config
        )
        mock_response: AuthenticateResponse = AuthenticateResponse()
        self.audio_biometrics_client.Authenticate = MagicMock(
            return_value=(mock_request, mock_response)
        )

        audio_service: MockAudioService = MockAudioService(
            config=self.config,
            token_manager=self.token_manager,
            audio_models_client=self.audio_models_client,
            audio_biometrics_client=self.audio_biometrics_client,
            audio_events_client=self.audio_events_client,
            audio_transcriptions_client=self.audio_transcriptions_client,
        )

        (
            authenticate_stream_request,
            authenticate_stream_response,
        ) = audio_service.stream_authenticate(
            audio_config=self.audio_config,
            enrollment_id=enrollment_id,
            is_liveness_enabled=is_liveness_enabled,
            audio_stream_iterator=None,
            sensitivity=sensitivity,
            security=security,
        )

        self.assertIsNotNone(authenticate_stream_response)

        config_message = authenticate_stream_request.config

        self.assertEqual(
            config_message.audio,
            self.audio_config,
            "Audio config should match what was passed in",
        )
        self.assertEqual(
            config_message.enrollmentId,
            enrollment_id,
            "Enrollment ID should match what was passed in",
        )
        self.assertEqual(
            config_message.enrollmentGroupId, "", "Enrollment group ID should be empty"
        )
        self.assertEqual(
            config_message.sensitivity,
            sensitivity,
            "Sensitivity name should match what was passed in",
        )
        self.assertEqual(
            config_message.security,
            security,
            "Security name should match what was passed in",
        )
        self.assertEqual(
            config_message.isLivenessEnabled,
            is_liveness_enabled,
            "Is liveness enabled should match what was passed in",
        )

        self.config.channel.close()

    def test_stream_group_authentication(self):
        self.config.connect()

        enrollment_group_id: str = "enrollment-id"
        is_liveness_enabled: bool = False

        sensitivity: ThresholdSensitivity = ThresholdSensitivity.Value("LOW")
        security: AuthenticateConfig.ThresholdSecurity = (
            AuthenticateConfig.ThresholdSecurity.Value("LOW")
        )
        authenticate_config: AuthenticateConfig = AuthenticateConfig(
            audio=self.audio_config,
            enrollmentGroupId=enrollment_group_id,
            sensitivity=sensitivity,
            security=security,
            isLivenessEnabled=is_liveness_enabled,
        )

        mock_request: AuthenticateRequest = AuthenticateRequest(
            config=authenticate_config
        )
        mock_response: AuthenticateResponse = AuthenticateResponse()
        self.audio_biometrics_client.Authenticate = MagicMock(
            return_value=(mock_request, mock_response)
        )

        audio_service = MockAudioService(
            config=self.config,
            token_manager=self.token_manager,
            audio_models_client=self.audio_models_client,
            audio_biometrics_client=self.audio_biometrics_client,
            audio_events_client=self.audio_events_client,
            audio_transcriptions_client=self.audio_transcriptions_client,
        )

        (
            authenticate_stream_request,
            authenticate_stream_response,
        ) = audio_service.stream_group_authenticate(
            audio_config=self.audio_config,
            enrollment_group_id=enrollment_group_id,
            is_liveness_enabled=is_liveness_enabled,
            audio_stream_iterator=None,
            sensitivity=sensitivity,
            security=security,
        )

        self.assertIsNotNone(authenticate_stream_response)

        config_message = authenticate_stream_request.config

        self.assertEqual(
            config_message.audio,
            self.audio_config,
            "Audio config should match what was passed in",
        )
        self.assertEqual(
            config_message.enrollmentGroupId,
            enrollment_group_id,
            "Enrollment group ID should match what was passed in",
        )
        self.assertEqual(
            config_message.enrollmentId, "", "Enrollment ID should be empty"
        )
        self.assertEqual(
            config_message.sensitivity,
            sensitivity,
            "Sensitivity name should match what was passed in",
        )
        self.assertEqual(
            config_message.security,
            security,
            "Security name should match what was passed in",
        )
        self.assertEqual(
            config_message.isLivenessEnabled,
            is_liveness_enabled,
            "Is liveness enabled should match what was passed in",
        )

        self.config.channel.close()

    def test_stream_event(self):
        self.config.connect()

        model_name: str = "my-model"
        user_id: str = "user-id"
        sensitivity: ThresholdSensitivity = ThresholdSensitivity.Value("LOW")

        event_config: ValidateEventConfig = ValidateEventConfig(
            audio=self.audio_config,
            modelName=model_name,
            userId=user_id,
            sensitivity=sensitivity,
        )

        mock_request: ValidateEventRequest = ValidateEventRequest(config=event_config)
        mock_response: ValidateEventResponse = ValidateEventResponse()

        self.audio_events_client.ValidateEvent = MagicMock(
            return_value=(mock_request, mock_response)
        )

        audio_service = MockAudioService(
            config=self.config,
            token_manager=self.token_manager,
            audio_models_client=self.audio_models_client,
            audio_biometrics_client=self.audio_biometrics_client,
            audio_events_client=self.audio_events_client,
            audio_transcriptions_client=self.audio_transcriptions_client,
        )

        event_stream_request, event_stream_response = audio_service.stream_event(
            audio_config=self.audio_config,
            user_id=user_id,
            model_name=model_name,
            audio_stream_iterator=None,
            sensitivity=sensitivity,
        )

        self.assertIsNotNone(event_stream_response)

        config_message = event_stream_request.config

        self.assertEqual(
            config_message.audio,
            self.audio_config,
            "Audio config should match what was passed in",
        )
        self.assertEqual(
            config_message.userId, user_id, "User ID should match what was passed in"
        )
        self.assertEqual(
            config_message.modelName,
            model_name,
            "Model name should match what was passed in",
        )
        self.assertEqual(
            config_message.sensitivity,
            sensitivity,
            "Sensitivity name should match what was passed in",
        )

        self.config.channel.close()

    def test_stream_create_enrolled_event(self):
        self.config.connect()

        user_id: str = "user-id"
        model_name: str = "my-model"
        description: str = "my-description"

        create_enrollment_event_config: CreateEnrollmentEventConfig = (
            CreateEnrollmentEventConfig(
                audio=self.audio_config,
                userId=user_id,
                modelName=model_name,
                description=description,
            )
        )

        mock_request: CreateEnrolledEventRequest = CreateEnrolledEventRequest(
            config=create_enrollment_event_config
        )
        mock_response: CreateEnrollmentResponse = CreateEnrollmentResponse()

        self.audio_events_client.CreateEnrolledEvent = MagicMock(
            return_value=(mock_request, mock_response)
        )

        audio_service = MockAudioService(
            config=self.config,
            token_manager=self.token_manager,
            audio_models_client=self.audio_models_client,
            audio_biometrics_client=self.audio_biometrics_client,
            audio_events_client=self.audio_events_client,
            audio_transcriptions_client=self.audio_transcriptions_client,
        )

        (
            enrollment_stream_request,
            enrollment_stream_response,
        ) = audio_service.stream_create_enrolled_event(
            audio_config=self.audio_config,
            description=description,
            user_id=user_id,
            model_name=model_name,
            audio_stream_iterator=None,
        )

        self.assertIsNotNone(
            enrollment_stream_response, "Enrollment stream should be returned"
        )

        config_message = enrollment_stream_request.config

        self.assertEqual(
            config_message.audio,
            self.audio_config,
            "Audio config should match what was passed in",
        )
        self.assertEqual(
            config_message.userId, user_id, "User ID should match what was passed in"
        )
        self.assertEqual(
            config_message.modelName,
            model_name,
            "Model name should match what was passed in",
        )

        self.config.channel.close()

    def test_stream_validate_enrolled_event(self):
        self.config.connect()

        enrollment_id: str = "enrollment-id"
        sensitivity: ThresholdSensitivity = ThresholdSensitivity.Value("HIGH")

        validate_enrolled_event_config = ValidateEnrolledEventConfig(
            audio=self.audio_config,
            enrollmentId=enrollment_id,
            sensitivity=sensitivity,
        )

        mock_request: ValidateEnrolledEventRequest = ValidateEnrolledEventRequest(
            config=validate_enrolled_event_config
        )
        mock_response: ValidateEnrolledEventResponse = ValidateEnrolledEventResponse()

        self.audio_events_client.ValidateEnrolledEvent = MagicMock(
            return_value=(mock_request, mock_response)
        )

        audio_service = MockAudioService(
            config=self.config,
            token_manager=self.token_manager,
            audio_models_client=self.audio_models_client,
            audio_biometrics_client=self.audio_biometrics_client,
            audio_events_client=self.audio_events_client,
            audio_transcriptions_client=self.audio_transcriptions_client,
        )

        (
            validate_enrolled_event_request,
            validate_enrolled_event_response,
        ) = audio_service.stream_validate_enrolled_event(
            audio_config=self.audio_config,
            enrollment_id=enrollment_id,
            audio_stream_iterator=None,
            sensitivity=sensitivity,
        )

        self.assertIsNotNone(
            validate_enrolled_event_response, "Event stream should be returned"
        )

        config_message = validate_enrolled_event_request.config

        self.assertEqual(
            config_message.audio,
            self.audio_config,
            "Audio config should match what was passed in",
        )
        self.assertEqual(
            config_message.enrollmentId,
            enrollment_id,
            "Enrollment ID should match what was passed in",
        )
        self.assertEqual(
            config_message.sensitivity,
            sensitivity,
            "Sensitivity should match what was passed in",
        )

        self.config.channel.close()

    def test_stream_group_validate_enrolled_event(self):
        self.config.connect()

        enrollment_group_id: str = "enrollment-group-id"
        sensitivity: ThresholdSensitivity = ThresholdSensitivity.Value("HIGHEST")

        validate_enrolled_event_config = ValidateEnrolledEventConfig(
            audio=self.audio_config,
            enrollmentGroupId=enrollment_group_id,
            sensitivity=sensitivity,
        )

        mock_request: ValidateEnrolledEventRequest = ValidateEnrolledEventRequest(
            config=validate_enrolled_event_config
        )
        mock_response: ValidateEnrolledEventResponse = ValidateEnrolledEventResponse()

        self.audio_events_client.ValidateEnrolledEvent = MagicMock(
            return_value=(mock_request, mock_response)
        )

        audio_service = MockAudioService(
            config=self.config,
            token_manager=self.token_manager,
            audio_models_client=self.audio_models_client,
            audio_biometrics_client=self.audio_biometrics_client,
            audio_events_client=self.audio_events_client,
            audio_transcriptions_client=self.audio_transcriptions_client,
        )

        (
            validate_enrolled_event_request,
            validate_enrolled_event_response,
        ) = audio_service.stream_group_validate_enrolled_event(
            audio_config=self.audio_config,
            enrollment_group_id=enrollment_group_id,
            audio_stream_iterator=None,
            sensitivity=sensitivity,
        )

        self.assertIsNotNone(
            validate_enrolled_event_response, "Event stream should be returned"
        )

        config_message = validate_enrolled_event_request.config

        self.assertEqual(
            config_message.audio,
            self.audio_config,
            "Audio config should match what was passed in",
        )
        self.assertEqual(
            config_message.enrollmentGroupId,
            enrollment_group_id,
            "Enrollment Group ID should match what was passed in",
        )
        self.assertEqual(
            config_message.sensitivity,
            sensitivity,
            "Sensitivity should match what was passed in",
        )

        self.config.channel.close()

    def test_stream_transcription(self):
        self.config.connect()

        user_id = "user-id"
        model_name = "model-name"
        enable_punctuation_capitalization = True

        transcribe_config: TranscribeConfig = TranscribeConfig(
            audio=self.audio_config,
            modelName=model_name,
            userId=user_id,
            enablePunctuationCapitalization=enable_punctuation_capitalization,
        )

        mock_request: TranscribeRequest = TranscribeRequest(config=transcribe_config)
        mock_response: TranscribeResponse = TranscribeResponse()

        self.audio_transcriptions_client.Transcribe = MagicMock(
            return_value=(mock_request, mock_response)
        )

        audio_service = MockAudioService(
            config=self.config,
            token_manager=self.token_manager,
            audio_models_client=self.audio_models_client,
            audio_biometrics_client=self.audio_biometrics_client,
            audio_events_client=self.audio_events_client,
            audio_transcriptions_client=self.audio_transcriptions_client,
        )

        (
            transcribe_stream_request,
            transcribe_stream_response,
        ) = audio_service.stream_transcription(
            audio_config=self.audio_config,
            user_id=user_id,
            model_name=model_name,
            enable_punctuation_capitalization=enable_punctuation_capitalization,
            audio_stream_iterator=None,
        )

        self.assertIsNotNone(transcribe_stream_response)

        config_message = transcribe_stream_request.config

        self.assertEqual(
            config_message.audio,
            self.audio_config,
            "Audio config should match what was passed in",
        )
        self.assertEqual(
            config_message.userId, user_id, "User ID should match what was passed in"
        )
        self.assertEqual(
            config_message.modelName,
            model_name,
            "Model name should match what was passed in",
        )
        self.assertEqual(
            config_message.enablePunctuationCapitalization,
            enable_punctuation_capitalization,
            "Enable punctation capitalization should match what was passed in",
        )

        self.config.channel.close()


if __name__ == "__main__":
    unittest.main()



import typing
from enum import Enum

from sensory_cloud.config import Config
from sensory_cloud.token_manager import ITokenManager, Metadata

import sensory_cloud.generated.v1.audio.audio_pb2_grpc as audio_pb2_grpc
import sensory_cloud.generated.v1.audio.audio_pb2 as audio_pb2


class AudioRequest(Enum):
    audio_pb2.CreateEnrollmentRequest
    audio_pb2.AuthenticateRequest
    audio_pb2.TranscribeRequest
    audio_pb2.ValidateEventRequest
    audio_pb2.CreateEnrolledEventRequest
    audio_pb2.ValidateEnrolledEventRequest


class RequestConfig(Enum):
    audio_pb2.CreateEnrollmentConfig
    audio_pb2.AuthenticateConfig
    audio_pb2.TranscribeConfig
    audio_pb2.ValidateEventConfig
    audio_pb2.CreateEnrollmentEventConfig


class RequestIterator:
    """
    The RequestIterator class facilitates the request streams that are sent to the
    grpc server.  There are six possible audio request types and and five request configurations
    that are given by the AudioRequest and RequestConfig enums respectively.  The first
    request sent must be a configuration request and all subsequent requests contain the audio
    content being streamed and any post processing actions if relevant.
    """

    _first_request: bool = True
    _post_processing_requests: set = {
        audio_pb2.TranscribeRequest,
        audio_pb2.ValidateEventRequest,
    }

    def __init__(
        self,
        audio_request: AudioRequest,
        request_config: RequestConfig,
        audio_stream_iterator: typing.Iterable[bytes],
    ):
        """
        Constructor method for the RequestIterator class

        Arguments:
            audio_request: AudioRequest enum denoting which type of request is being sent
            request_config: RequestConfig enum containing the initial request configuration
            audio_stream_iterator: Iterator containing audio bytes
        """

        self._audio_request = audio_request
        self._request_config = request_config
        self._audio_stream_iterator = audio_stream_iterator

    def __iter__(self):
        return self

    def __next__(self) -> AudioRequest:
        if self._first_request:
            self._first_request = False
            return self._audio_request(config=self._request_config)
        else:
            audio_content, post_processing_action = next(self._audio_stream_iterator)
            if self._audio_request in self._post_processing_requests:
                _request = self._audio_request(
                    audioContent=audio_content,
                    postProcessingAction=post_processing_action,
                )
            else:
                _request = self._audio_request(audioContent=audio_content)
        return _request


class TranscriptAggregator:
    """
    A class that aggregates and stores transcription responses
    """

    def __init__(self):
        """
        Constructor method for the TranscriptAggregator class
        """

        self._word_list: typing.List[audio_pb2.TranscribeWord] = []
        self._response_list: typing.List[audio_pb2.TranscribeResponse] = []
        self.is_stream_finalized: bool = False

    @property
    def word_list(self) -> typing.List[audio_pb2.TranscribeWord]:
        """
        Get method that returns the word list attribute
        """
        return self._word_list

    @property
    def response_list(self) -> typing.List[audio_pb2.TranscribeResponse]:
        """
        Get method that returns the word list attribute
        """
        return self._response_list

    def process_response(self, response: audio_pb2.TranscribeResponse) -> None:
        """
        Method that processes a single sliding-window response from the server
        """

        self.is_stream_finalized = (
            response.postProcessingAction.action
            == audio_pb2.AudioPostProcessingAction.FINAL
        )

        self._response_list.append(response)
        if len(response.wordList.words) == 0:
            return
        word_count: int = response.wordList.lastWordIndex + 1
        self._word_list += [""] * (word_count - len(self._word_list))
        for item in response.wordList.words:
            self._word_list[item.wordIndex] = item
        self._word_list = self._word_list[:word_count]

    def get_transcript(self, delimiter: str = " ") -> str:
        """
        Method that concatenates the self._word_list attribute using the specified
        delimiter

        Arguments:
            delimiter (str): string used for delimiting the concatenation of the
                self._word_list attribute

        Returns:
            A concatenated string of the most current full transcript
        """

        if len(self._word_list) == 0:
            return ""
        transcript: str = delimiter.join(
            [item.word for item in self._word_list]
        ).strip()

        return transcript


class AudioService:
    """
    Class that handles all audio requests to Sensory Cloud
    """

    def __init__(self, config: Config, token_manager: ITokenManager):
        """
        Constructor method for the AudioService class

        Arguments:
            config: Config object containing the relevant grpc connection information
            token_manager: ITokenManager object that generates and returns JWT metadata
        """

        self._config: Config = config
        self._token_manager: ITokenManager = token_manager
        self._audio_models_client: audio_pb2_grpc.AudioModelsStub = (
            audio_pb2_grpc.AudioModelsStub(config.channel)
        )
        self._audio_biometrics_client: audio_pb2_grpc.AudioBiometricsStub = (
            audio_pb2_grpc.AudioBiometricsStub(config.channel)
        )
        self._audio_events_client: audio_pb2_grpc.AudioEventsStub = (
            audio_pb2_grpc.AudioEventsStub(config.channel)
        )
        self._audio_transcriptions_client: audio_pb2_grpc.AudioTranscriptionsStub = (
            audio_pb2_grpc.AudioTranscriptionsStub(config.channel)
        )
        self._audio_synthesis_client: audio_pb2_grpc.AudioSynthesisStub = (
            audio_pb2_grpc.AudioSynthesisStub(config.channel)
        )

    def get_models(self) -> audio_pb2.GetModelsResponse:
        """
        Method that fetches all the audio models supported by your instance of Sensory Cloud.

        Returns:
            A GetModelsResponse containing information about all audio models
        """

        request: audio_pb2.GetModelsRequest = audio_pb2.GetModelsRequest()

        metadata: Metadata = self._token_manager.get_authorization_metadata()

        models: audio_pb2.GetModelsResponse = self._audio_models_client.GetModels(
            request=request, metadata=metadata
        )

        return models

    def stream_enrollment(
        self,
        audio_config: audio_pb2.AudioConfig,
        description: str,
        user_id: str,
        device_id: str,
        model_name: str,
        is_liveness_enabled: bool,
        audio_stream_iterator: typing.Iterable[bytes],
    ) -> typing.Iterable[audio_pb2.CreateEnrollmentResponse]:
        """
        Stream audio to Sensory Cloud as a means for user enrollment.
        Only biometric-typed models are supported by the method.

        Arguments:
            audio_config: AudioConfig object
            description: String containing a description of the enrollment
            user_id: String containing the user id
            device_id: String containing the device id
            model_name: String containing the model name
            is_liveness_enabled: Boolean indicating whether or not liveness is enabled
            audio_stream_iterator: Iterator of audio bytes

        Returns:
            An iterator of CreateEnrollmentResponse objects
        """

        config: audio_pb2.CreateEnrollmentConfig = audio_pb2.CreateEnrollmentConfig(
            audio=audio_config,
            description=description,
            userId=user_id,
            modelName=model_name,
            deviceId=device_id,
            isLivenessEnabled=is_liveness_enabled,
        )

        request_iterator: RequestIterator = RequestIterator(
            audio_request=audio_pb2.CreateEnrollmentRequest,
            request_config=config,
            audio_stream_iterator=audio_stream_iterator,
        )

        metadata: Metadata = self._token_manager.get_authorization_metadata()

        enrollment_stream: typing.Iterable[
            audio_pb2.CreateEnrollmentResponse
        ] = self._audio_biometrics_client.CreateEnrollment(
            request_iterator=request_iterator, metadata=metadata
        )

        return enrollment_stream

    def stream_authenticate(
        self,
        audio_config: audio_pb2.AudioConfig,
        enrollment_id: str,
        is_liveness_enabled: bool,
        audio_stream_iterator: typing.Iterable[bytes],
        sensitivity: audio_pb2.ThresholdSensitivity = audio_pb2.ThresholdSensitivity.Value(
            "MEDIUM"
        ),
        security: audio_pb2.AuthenticateConfig.ThresholdSecurity = audio_pb2.AuthenticateConfig.ThresholdSecurity.Value(
            "HIGH"
        ),
    ) -> typing.Iterable[audio_pb2.AuthenticateResponse]:
        """
        Authenticate against an existing audio enrollment in Sensory Cloud.
        Only biometric-typed models are supported by the method.

        Arguments:
            audio_config: AudioConfig object
            enrollment_id: String containing the enrollment id to authenticate on
            is_liveness_enabled: Boolean indicating whether or not liveness is enabled
            audio_stream_iterator: Iterator of audio bytes
            sensitivity: ThresholdSensitivity enum that sets the sensitivity level of the authentication
                default = ThresholdSensitivity.Value("MEDIUM")
            security: AuthenticateConfig.ThresholdSecurity that sets the security level of the authentication
                default = AuthenticateConfig.ThresholdSecurity.Value("HIGH")

        Returns:
            An iterator of AuthenticateResponse objects
        """

        authenticate_config: audio_pb2.AuthenticateConfig = (
            audio_pb2.AuthenticateConfig(
                audio=audio_config,
                enrollmentId=enrollment_id,
                sensitivity=sensitivity,
                security=security,
                isLivenessEnabled=is_liveness_enabled,
            )
        )

        authenticate_stream: typing.Iterable[
            audio_pb2.AuthenticateResponse
        ] = self._stream_authentication(
            config=authenticate_config, audio_stream_iterator=audio_stream_iterator
        )

        return authenticate_stream

    def stream_group_authenticate(
        self,
        audio_config: audio_pb2.AudioConfig,
        enrollment_group_id: str,
        is_liveness_enabled: bool,
        audio_stream_iterator: typing.Iterable[bytes],
        sensitivity: audio_pb2.ThresholdSensitivity = audio_pb2.ThresholdSensitivity.Value(
            "MEDIUM"
        ),
        security: audio_pb2.AuthenticateConfig.ThresholdSecurity = audio_pb2.AuthenticateConfig.ThresholdSecurity.Value(
            "HIGH"
        ),
    ) -> typing.Iterable[audio_pb2.AuthenticateResponse]:
        """
        Authenticate against an existing audio enrollment in Sensory Cloud.

        Arguments:
            audio_config: AudioConfig object
            enrollment_group_id: String containing the enrollment group id to authenticate on
            is_liveness_enabled: Boolean indicating whether or not liveness is enabled
            audio_stream_iterator: Iterator of audio bytes
            sensitivity: ThresholdSensitivity enum that sets the sensitivity level of the authentication
                default = ThresholdSensitivity.Value("MEDIUM")
            security: AuthenticateConfig.ThresholdSecurity that sets the security level of the authentication
                default = AuthenticateConfig.ThresholdSecurity.Value("HIGH")

        Returns:
            An iterator of AuthenticateResponse objects
        """

        authenticate_config: audio_pb2.AuthenticateConfig = (
            audio_pb2.AuthenticateConfig(
                audio=audio_config,
                enrollmentGroupId=enrollment_group_id,
                sensitivity=sensitivity,
                security=security,
                isLivenessEnabled=is_liveness_enabled,
            )
        )

        group_authenticate_stream: typing.Iterable[
            audio_pb2.AuthenticateResponse
        ] = self._stream_authentication(
            config=authenticate_config, audio_stream_iterator=audio_stream_iterator
        )

        return group_authenticate_stream

    def stream_event(
        self,
        audio_config: audio_pb2.AudioConfig,
        user_id: str,
        model_name: str,
        audio_stream_iterator: typing.Iterable[bytes],
        sensitivity: audio_pb2.ThresholdSensitivity = audio_pb2.ThresholdSensitivity.Value(
            "MEDIUM"
        ),
    ) -> typing.Iterable[audio_pb2.ValidateEventResponse]:
        """
        Stream audio to Sensory Cloud in order to recognize a specific phrase or sound

        Arguments:
            audio_config: AudioConfig object
            user_id: String containing the user id
            model_name: String containing the name of the model to be used
            audio_stream_iterator: Iterator of audio bytes
            sensitivity: ThresholdSensitivity enum that sets the sensitivity level of the authentication
                default = ThresholdSensitivity.Value("MEDIUM")

        Returns:
            An iterator of ValidateEventResponse objects
        """

        config = audio_pb2.ValidateEventConfig(
            audio=audio_config,
            modelName=model_name,
            userId=user_id,
            sensitivity=sensitivity,
        )

        request_iterator: RequestIterator = RequestIterator(
            audio_request=audio_pb2.ValidateEventRequest,
            request_config=config,
            audio_stream_iterator=audio_stream_iterator,
        )

        metadata: Metadata = self._token_manager.get_authorization_metadata()

        event_stream: typing.Iterable[
            audio_pb2.ValidateEventResponse
        ] = self._audio_events_client.ValidateEvent(
            request_iterator=request_iterator, metadata=metadata
        )

        return event_stream

    def stream_create_enrolled_event(
        self,
        audio_config: audio_pb2.AudioConfig,
        description: str,
        user_id: str,
        model_name: str,
        audio_stream_iterator: typing.Iterable[bytes],
    ) -> typing.Iterable[audio_pb2.CreateEnrollmentResponse]:
        """
        Stream audio to Sensory Cloud as a means for audio enrollment.
        This method is similar to StreamEnrollment, but does not have the same
        time limits or model type restrictions.
        Biometric model types are not supported by this function.
        This endpoint cannot be used to establish device trust.

        Arguments:
            audio_config: AudioConfig object
            description: String containing a description of this enrollment.
                Useful if a user could have multiple enrollments, as it helps differentiate between them.
            user_id: String containing the user id
            model_name: String containing the name of the model to be used
            audio_stream_iterator: Iterator of audio bytes

        Returns:
            An iterator of CreateEnrollmentResponse objects
        """

        config: audio_pb2.CreateEnrollmentEventConfig = (
            audio_pb2.CreateEnrollmentEventConfig(
                audio=audio_config,
                userId=user_id,
                modelName=model_name,
                description=description,
            )
        )

        request_iterator: RequestIterator = RequestIterator(
            audio_request=audio_pb2.CreateEnrolledEventRequest,
            request_config=config,
            audio_stream_iterator=audio_stream_iterator,
        )

        metadata: Metadata = self._token_manager.get_authorization_metadata()

        enrollment_stream: typing.Iterable[
            audio_pb2.CreateEnrollmentResponse
        ] = self._audio_events_client.CreateEnrolledEvent(
            request_iterator=request_iterator, metadata=metadata
        )

        return enrollment_stream

    def stream_validate_enrolled_event(
        self,
        audio_config: audio_pb2.AudioConfig,
        enrollment_id: str,
        audio_stream_iterator: typing.Iterable[bytes],
        sensitivity: audio_pb2.ThresholdSensitivity = audio_pb2.ThresholdSensitivity.Value(
            "MEDIUM"
        ),
    ) -> typing.Iterable[audio_pb2.ValidateEnrolledEventResponse]:
        """
        Validate an existing event enrollment in Sensory Cloud.
        This method is similar to Authenticate, but does not have the same
        time limits or model type restrictions. Additionally, the server will
        never close the stream, and thus a client may validate an enrolled sound
        as many times as they'd like.
        Any model types are supported by this function.
        This endpoint cannot be used to establish device trust.

        Arguments:
            audio_config: AudioConfig object
            enrollment_id: String containing the enrollment id
            audio_stream_iterator: Iterator of audio bytes
            sensitivity: ThresholdSensitivity enum that sets the sensitivity level of the authentication
                default = ThresholdSensitivity.Value("MEDIUM")

        Returns:
            An iterator of ValidateEnrolledEventResponse objects
        """

        config = audio_pb2.ValidateEnrolledEventConfig(
            audio=audio_config,
            enrollmentId=enrollment_id,
            sensitivity=sensitivity,
        )

        validate_enrolled_event_stream: typing.Iterable[
            audio_pb2.ValidateEnrolledEventResponse
        ] = self._stream_event_validation(
            config=config, audio_stream_iterator=audio_stream_iterator
        )

        return validate_enrolled_event_stream

    def stream_group_validate_enrolled_event(
        self,
        audio_config: audio_pb2.AudioConfig,
        enrollment_group_id: str,
        audio_stream_iterator: typing.Iterable[bytes],
        sensitivity: audio_pb2.ThresholdSensitivity = audio_pb2.ThresholdSensitivity.Value(
            "MEDIUM"
        ),
    ) -> typing.Iterable[audio_pb2.ValidateEnrolledEventResponse]:
        """
        Validate an existing groupd of events in Sensory Cloud.
        This method is similar to GroupAuthenticate, but does not have the same
        time limits or model type restrictions. Additionally, the server will
        never close the stream, and thus a client may validate an enrolled group
        as many times as they'd like.
        Any model types are supported by this function.
        This endpoint cannot be used to establish device trust.

        Arguments:
            audio_config: AudioConfig object
            enrollment_group_id: String containing the enrollment group id
            audio_stream_iterator: Iterator of audio bytes
            sensitivity: ThresholdSensitivity enum that sets the sensitivity level of the authentication
                default = ThresholdSensitivity.Value("MEDIUM")

        Returns:
            An iterator of ValidateEnrolledEventResponse objects
        """

        config = audio_pb2.ValidateEnrolledEventConfig(
            audio=audio_config,
            enrollmentGroupId=enrollment_group_id,
            sensitivity=sensitivity,
        )

        validate_enrolled_event_stream: typing.Iterable[
            audio_pb2.ValidateEnrolledEventResponse
        ] = self._stream_event_validation(
            config=config, audio_stream_iterator=audio_stream_iterator
        )

        return validate_enrolled_event_stream

    def stream_transcription(
        self,
        audio_config: audio_pb2.AudioConfig,
        user_id: str,
        model_name: str,
        audio_stream_iterator: typing.Iterable[bytes],
        enable_punctuation_capitalization: bool = False,
        do_single_utterance: bool = False,
        vad_sensitivity: audio_pb2.ThresholdSensitivity = None,
        vad_duration: float = None,
        custom_vocab_reward_threshold: audio_pb2.ThresholdSensitivity = None,
        custom_vocabulary_id: str = None,
        custom_word_list: typing.List[str] = None,
    ) -> typing.Iterable[audio_pb2.TranscribeResponse]:
        """
        Stream audio to Sensory Cloud in order to transcribe spoken words

        Arguments:
            audio_config: AudioConfig object
            user_id: String containing the user id
            model_name: String containing the name of the model to be used
            audio_stream_iterator: Iterator of audio bytes

        Returns:
            An iterator of TranscribeResponse objects
        """

        custom_vocab = (
            audio_pb2.CustomVocabularyWords(words=custom_word_list)
            if custom_word_list is not None
            else None
        )

        config: audio_pb2.TranscribeConfig = audio_pb2.TranscribeConfig(
            audio=audio_config,
            modelName=model_name,
            userId=user_id,
            enablePunctuationCapitalization=enable_punctuation_capitalization,
            doSingleUtterance=do_single_utterance,
            vadSensitivity=vad_sensitivity,
            vadDuration=vad_duration,
            customVocabRewardThreshold=custom_vocab_reward_threshold,
            customVocabularyId=custom_vocabulary_id,
            customWordList=custom_vocab,
        )

        request_iterator: RequestIterator = RequestIterator(
            audio_request=audio_pb2.TranscribeRequest,
            request_config=config,
            audio_stream_iterator=audio_stream_iterator,
        )

        metadata: Metadata = self._token_manager.get_authorization_metadata()

        transcription_stream: typing.Iterable[
            audio_pb2.TranscribeResponse
        ] = self._audio_transcriptions_client.Transcribe(
            request_iterator=request_iterator, metadata=metadata
        )

        return transcription_stream

    def synthesize_speech(
        self,
        sample_rate_hz: int,
        phrase: str,
        model_name: str,
    ) -> typing.Iterable[audio_pb2.SynthesizeSpeechResponse]:
        """
        Sends a request to Sensory Cloud to synthesize speech

        Arguments:
            sample_rate_hz (int): The sample rate in Hz for the returned audio
            phrase (str): The text phrase to synthesize a voice saying
            model_name (str): The name of the model to use during speech synthesis

        Returns:
            An iterator containing audio bytes of the synthesized phrase
        """

        voice_synthesis_config: audio_pb2.VoiceSynthesisConfig = (
            audio_pb2.VoiceSynthesisConfig(
                modelName=model_name,
                sampleRateHertz=sample_rate_hz,
            )
        )

        request: audio_pb2.SynthesizeSpeechRequest = audio_pb2.SynthesizeSpeechRequest(
            phrase=phrase,
            config=voice_synthesis_config,
        )

        metadata: Metadata = self._token_manager.get_authorization_metadata()

        synthesis_stream: typing.Iterable[
            audio_pb2.SynthesizeSpeechResponse
        ] = self._audio_synthesis_client.SynthesizeSpeech(
            request=request, metadata=metadata
        )

        return synthesis_stream

    def _stream_authentication(
        self,
        config: audio_pb2.AuthenticateConfig,
        audio_stream_iterator: typing.Iterable[bytes],
    ) -> typing.Iterable[audio_pb2.AuthenticateResponse]:
        """
        Private method behind the public authentication methods

        Arguments:
            config: AuthenticateConfig object containing authentication configuration parameters

        Returns:
            An iterator of AuthenticateResponse objects
        """

        request_iterator: RequestIterator = RequestIterator(
            audio_request=audio_pb2.AuthenticateRequest,
            request_config=config,
            audio_stream_iterator=audio_stream_iterator,
        )

        metadata: Metadata = self._token_manager.get_authorization_metadata()

        authenticate_stream: typing.Iterable[
            audio_pb2.AuthenticateResponse
        ] = self._audio_biometrics_client.Authenticate(
            request_iterator=request_iterator, metadata=metadata
        )

        return authenticate_stream

    def _stream_event_validation(
        self,
        config: audio_pb2.ValidateEnrolledEventConfig,
        audio_stream_iterator: typing.Iterable[bytes],
    ) -> typing.Iterable[audio_pb2.ValidateEnrolledEventResponse]:
        """
        Private method behind the public event validation methods

        Arguments:
            config: ValidateEnrolledEventConfig object containing enrolled event configuration parameters

        Returns:
            An iterator of ValidateEnrolledEventResponse objects
        """

        request_iterator: RequestIterator = RequestIterator(
            audio_request=audio_pb2.ValidateEnrolledEventRequest,
            request_config=config,
            audio_stream_iterator=audio_stream_iterator,
        )

        metadata: Metadata = self._token_manager.get_authorization_metadata()

        validate_enrolled_event_stream: typing.Iterable[
            audio_pb2.ValidateEnrolledEventResponse
        ] = self._audio_events_client.ValidateEnrolledEvent(
            request_iterator=request_iterator, metadata=metadata
        )

        return validate_enrolled_event_stream



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from sensory_cloud.generated.v1.video import video_pb2 as v1_dot_video_dot_video__pb2


class VideoModelsStub(object):
    """Handles the retrieval and management of video models
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetModels = channel.unary_unary(
                '/sensory.api.v1.video.VideoModels/GetModels',
                request_serializer=v1_dot_video_dot_video__pb2.GetModelsRequest.SerializeToString,
                response_deserializer=v1_dot_video_dot_video__pb2.GetModelsResponse.FromString,
                )


class VideoModelsServicer(object):
    """Handles the retrieval and management of video models
    """

    def GetModels(self, request, context):
        """Get available models for enrollment and authentication
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VideoModelsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetModels': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModels,
                    request_deserializer=v1_dot_video_dot_video__pb2.GetModelsRequest.FromString,
                    response_serializer=v1_dot_video_dot_video__pb2.GetModelsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sensory.api.v1.video.VideoModels', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VideoModels(object):
    """Handles the retrieval and management of video models
    """

    @staticmethod
    def GetModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.video.VideoModels/GetModels',
            v1_dot_video_dot_video__pb2.GetModelsRequest.SerializeToString,
            v1_dot_video_dot_video__pb2.GetModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class VideoBiometricsStub(object):
    """Handles all video-related biometrics
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateEnrollment = channel.stream_stream(
                '/sensory.api.v1.video.VideoBiometrics/CreateEnrollment',
                request_serializer=v1_dot_video_dot_video__pb2.CreateEnrollmentRequest.SerializeToString,
                response_deserializer=v1_dot_video_dot_video__pb2.CreateEnrollmentResponse.FromString,
                )
        self.Authenticate = channel.stream_stream(
                '/sensory.api.v1.video.VideoBiometrics/Authenticate',
                request_serializer=v1_dot_video_dot_video__pb2.AuthenticateRequest.SerializeToString,
                response_deserializer=v1_dot_video_dot_video__pb2.AuthenticateResponse.FromString,
                )


class VideoBiometricsServicer(object):
    """Handles all video-related biometrics
    """

    def CreateEnrollment(self, request_iterator, context):
        """Enrolls a user with a stream of video. Streams a CreateEnrollmentResponse
        as the video is processed.
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Authenticate(self, request_iterator, context):
        """Authenticates a user with a stream of video against an existing enrollment.
        Streams an AuthenticateResponse as the video is processed.
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VideoBiometricsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateEnrollment': grpc.stream_stream_rpc_method_handler(
                    servicer.CreateEnrollment,
                    request_deserializer=v1_dot_video_dot_video__pb2.CreateEnrollmentRequest.FromString,
                    response_serializer=v1_dot_video_dot_video__pb2.CreateEnrollmentResponse.SerializeToString,
            ),
            'Authenticate': grpc.stream_stream_rpc_method_handler(
                    servicer.Authenticate,
                    request_deserializer=v1_dot_video_dot_video__pb2.AuthenticateRequest.FromString,
                    response_serializer=v1_dot_video_dot_video__pb2.AuthenticateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sensory.api.v1.video.VideoBiometrics', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VideoBiometrics(object):
    """Handles all video-related biometrics
    """

    @staticmethod
    def CreateEnrollment(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/sensory.api.v1.video.VideoBiometrics/CreateEnrollment',
            v1_dot_video_dot_video__pb2.CreateEnrollmentRequest.SerializeToString,
            v1_dot_video_dot_video__pb2.CreateEnrollmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Authenticate(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/sensory.api.v1.video.VideoBiometrics/Authenticate',
            v1_dot_video_dot_video__pb2.AuthenticateRequest.SerializeToString,
            v1_dot_video_dot_video__pb2.AuthenticateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class VideoRecognitionStub(object):
    """Handles all video recognition endpoints
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ValidateLiveness = channel.stream_stream(
                '/sensory.api.v1.video.VideoRecognition/ValidateLiveness',
                request_serializer=v1_dot_video_dot_video__pb2.ValidateRecognitionRequest.SerializeToString,
                response_deserializer=v1_dot_video_dot_video__pb2.LivenessRecognitionResponse.FromString,
                )


class VideoRecognitionServicer(object):
    """Handles all video recognition endpoints
    """

    def ValidateLiveness(self, request_iterator, context):
        """Validates the liveness of a single image or stream of images.
        Streams a ValidateRecognitionResponse as the images are processed.
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VideoRecognitionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ValidateLiveness': grpc.stream_stream_rpc_method_handler(
                    servicer.ValidateLiveness,
                    request_deserializer=v1_dot_video_dot_video__pb2.ValidateRecognitionRequest.FromString,
                    response_serializer=v1_dot_video_dot_video__pb2.LivenessRecognitionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sensory.api.v1.video.VideoRecognition', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VideoRecognition(object):
    """Handles all video recognition endpoints
    """

    @staticmethod
    def ValidateLiveness(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/sensory.api.v1.video.VideoRecognition/ValidateLiveness',
            v1_dot_video_dot_video__pb2.ValidateRecognitionRequest.SerializeToString,
            v1_dot_video_dot_video__pb2.LivenessRecognitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import datetime
import re
import unittest
from unittest.mock import MagicMock

from sensory_cloud.config import Config, CloudHost
from sensory_cloud.services.oauth_service import (
    IOauthService,
    ISecureCredentialStore,
    OAuthToken,
    OauthService,
)

import sensory_cloud.generated.common.common_pb2 as common_pb2
import sensory_cloud.generated.v1.management.device_pb2 as device_pb2
import sensory_cloud.generated.v1.management.device_pb2_grpc as device_pb2_grpc
import sensory_cloud.generated.oauth.oauth_pb2_grpc as oauth_pb2_grpc


def is_valid_guuid(str):

    # Regex to check valid
    # GUID (Globally Unique Identifier)
    regex = "^[{]?[0-9a-fA-F]{8}" + "-([0-9a-fA-F]{4}-)" + "{3}[0-9a-fA-F]{12}[}]?$"

    # Compile the ReGex
    p = re.compile(regex)

    # If the string is empty
    # return false
    if str == None:
        return False

    # Return if the string
    # matched the ReGex
    if re.search(p, str):
        return True
    else:
        return False


class MockCredentialStore(ISecureCredentialStore):
    def __init__(self, client_id, client_secret):
        self._client_id = client_id
        self._client_secret = client_secret

    @property
    def client_id(self):
        return self._client_id

    @property
    def client_secret(self):
        return self._client_secret


class MockOAuthService(OauthService):
    def __init__(
        self,
        config: Config,
        secure_credential_store: ISecureCredentialStore,
        oauth_client: oauth_pb2_grpc.OauthServiceStub,
        device_client: device_pb2_grpc.DeviceServiceStub,
    ):

        self._config: Config = config
        self._oauth_client: oauth_pb2_grpc.OauthServiceStub = oauth_client
        self._device_client: device_pb2_grpc.DeviceServiceStub = device_client
        self._secure_credential_store: ISecureCredentialStore = secure_credential_store


class OauthServiceTest(unittest.TestCase):
    cloud_host: CloudHost = CloudHost(host="domain.name")
    config: Config = Config(cloud_host=cloud_host, tenant_id="tenant-id")
    config.connect()

    oauth_client: oauth_pb2_grpc.OauthServiceStub = oauth_pb2_grpc.OauthServiceStub(
        config.channel
    )
    device_client: device_pb2_grpc.DeviceServiceStub = (
        device_pb2_grpc.DeviceServiceStub(config.channel)
    )

    def test_generate_credentials(self):
        self.config.connect()

        credential_store: MockCredentialStore = MockCredentialStore(
            client_id="client-id", client_secret="client-secret"
        )

        oauth_service: MockOAuthService = MockOAuthService(
            config=self.config,
            secure_credential_store=credential_store,
            oauth_client=self.oauth_client,
            device_client=self.device_client,
        )

        credentials = oauth_service.generate_credentials()

        self.assertTrue(
            is_valid_guuid(credentials.client_id),
            "The generated clientId should be a valid GUID",
        )
        self.assertEqual(
            len(credentials.client_secret),
            24,
            "The generated secret should be exactly 24 characters",
        )

        self.config.channel.close()

    def test_get_who_am_i(self):
        self.config.connect()

        credential_store: MockCredentialStore = MockCredentialStore(
            client_id="client-id", client_secret="client-secret"
        )

        mock_token_response: common_pb2.TokenResponse = common_pb2.TokenResponse(
            accessToken="my-token", expiresIn=0
        )
        self.oauth_client.GetToken = MagicMock(return_value=mock_token_response)

        mock_device_response: device_pb2.DeviceResponse = device_pb2.DeviceResponse(
            name="my-device-name", deviceId="my-device-id"
        )
        self.device_client.GetWhoAmI = MagicMock(return_value=mock_device_response)

        oauth_service: MockOAuthService = MockOAuthService(
            config=self.config,
            secure_credential_store=credential_store,
            oauth_client=self.oauth_client,
            device_client=self.device_client,
        )

        device_response: device_pb2.DeviceResponse = oauth_service.get_who_am_i()

        self.assertEqual(
            device_response,
            mock_device_response,
            "the who am I response should be correct",
        )

        self.config.channel.close()

    def test_get_token_null_credentials(self):
        self.config.connect()

        null_id_credential_store: MockCredentialStore = MockCredentialStore(
            client_id=None, client_secret="client-secret"
        )

        oauth_service: OauthService = OauthService(
            config=self.config, secure_credential_store=null_id_credential_store
        )

        self.assertRaises(ValueError, oauth_service.get_token)

        null_secret_credential_store: MockCredentialStore = MockCredentialStore(
            client_id="client-id", client_secret=""
        )
        oauth_service: OauthService = OauthService(
            config=self.config, secure_credential_store=null_secret_credential_store
        )

        self.assertRaises(ValueError, oauth_service.get_token)

        self.config.channel.close()

    def test_get_token(self):
        self.config.connect()

        credential_store: MockCredentialStore = MockCredentialStore(
            client_id="client-id", client_secret="client-secret"
        )

        token_response: common_pb2.TokenResponse = common_pb2.TokenResponse(
            accessToken="fake-token", expiresIn=0
        )
        self.oauth_client.GetToken = self.oauth_client.GetToken = MagicMock(
            return_value=token_response
        )

        oauth_service: MockOAuthService = MockOAuthService(
            config=self.config,
            secure_credential_store=credential_store,
            oauth_client=self.oauth_client,
            device_client=self.device_client,
        )

        oauth_token: OAuthToken = oauth_service.get_token()

        self.assertEqual(
            oauth_token.token,
            token_response.accessToken,
            "Returned access token should be the same",
        )
        self.assertTrue(
            oauth_token.expires <= datetime.datetime.utcnow(),
            "Token expiration should be earlier than or equal to now",
        )

        self.config.channel.close()

    def test_register_null_credentials(self):
        self.config.connect()

        device_name = "device-name"
        device_id = "device-id"
        credential = "credential"

        null_id_credential_store: MockCredentialStore = MockCredentialStore(
            client_id=None, client_secret="client-secret"
        )
        oauth_service: OauthService = OauthService(
            config=self.config, secure_credential_store=null_id_credential_store
        )
        self.assertRaises(
            ValueError, oauth_service.register, device_id, device_name, credential
        )

        null_secret_credential_store: MockCredentialStore = MockCredentialStore(
            client_id="client-id", client_secret=""
        )
        oauth_service: OauthService = OauthService(
            config=self.config, secure_credential_store=null_secret_credential_store
        )
        self.assertRaises(
            ValueError, oauth_service.register, device_id, device_name, credential
        )

        self.config.channel.close()

    def test_register(self):
        self.config.connect()

        device_name: str = "device-name"
        device_id: str = "device-id"
        credential: str = "my-credential"

        credential_store: MockCredentialStore = MockCredentialStore(
            client_id="client-id", client_secret="client-secret"
        )

        response: device_pb2.DeviceResponse = device_pb2.DeviceResponse(
            name=device_name, deviceId=device_id
        )
        self.device_client.EnrollDevice = MagicMock(return_value=response)

        oauth_service: MockOAuthService = MockOAuthService(
            config=self.config,
            secure_credential_store=credential_store,
            oauth_client=self.oauth_client,
            device_client=self.device_client,
        )

        device_response: device_pb2.DeviceResponse = oauth_service.register(
            device_id=device_id, device_name=device_name, credential=credential
        )

        self.assertEqual(
            response.name,
            device_response.name,
            "Returned device name should be the same",
        )
        self.assertEqual(
            response.deviceId,
            device_response.deviceId,
            "Returned device id should be the same",
        )

        self.config.channel.close()

    def test_renew_device_credential(self):
        self.config.connect()

        device_id: str = "device-id"
        credential: str = "my-credential"

        credential_store: MockCredentialStore = MockCredentialStore(
            client_id="client-id", client_secret="client-secret"
        )

        mock_token_response: common_pb2.TokenResponse = common_pb2.TokenResponse(
            accessToken="my-token", expiresIn=0
        )
        self.oauth_client.GetToken = MagicMock(return_value=mock_token_response)

        mock_device_response: device_pb2.DeviceResponse = device_pb2.DeviceResponse(
            name="my-device-name", deviceId=device_id
        )
        self.device_client.RenewDeviceCredential = MagicMock(
            return_value=mock_device_response
        )

        oauth_service: MockOAuthService = MockOAuthService(
            config=self.config,
            secure_credential_store=credential_store,
            oauth_client=self.oauth_client,
            device_client=self.device_client,
        )

        device_response: device_pb2.DeviceResponse = (
            oauth_service.renew_device_credential(
                device_id=device_id, credential=credential
            )
        )

        self.assertEqual(
            device_response,
            mock_device_response,
            "the who am I response should be correct",
        )

        self.config.channel.close()


if __name__ == "__main__":
    unittest.main()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from sensory_cloud.generated.v1.file import file_pb2 as v1_dot_file_dot_file__pb2


class FileStub(object):
    """Handles all file-related functions
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetInfo = channel.unary_unary(
                '/sensory.api.v1.file.File/GetInfo',
                request_serializer=v1_dot_file_dot_file__pb2.FileRequest.SerializeToString,
                response_deserializer=v1_dot_file_dot_file__pb2.FileInfo.FromString,
                )
        self.GetCatalog = channel.unary_unary(
                '/sensory.api.v1.file.File/GetCatalog',
                request_serializer=v1_dot_file_dot_file__pb2.FileCatalogRequest.SerializeToString,
                response_deserializer=v1_dot_file_dot_file__pb2.FileCatalogResponse.FromString,
                )
        self.GetCompleteCatalog = channel.unary_unary(
                '/sensory.api.v1.file.File/GetCompleteCatalog',
                request_serializer=v1_dot_file_dot_file__pb2.FileCompleteCatalogRequest.SerializeToString,
                response_deserializer=v1_dot_file_dot_file__pb2.FileCatalogResponse.FromString,
                )
        self.Download = channel.unary_stream(
                '/sensory.api.v1.file.File/Download',
                request_serializer=v1_dot_file_dot_file__pb2.FileRequest.SerializeToString,
                response_deserializer=v1_dot_file_dot_file__pb2.FileResponse.FromString,
                )


class FileServicer(object):
    """Handles all file-related functions
    """

    def GetInfo(self, request, context):
        """Allows a client to request information about a file in the cloud.
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCatalog(self, request, context):
        """Allows a client to request a list of all the files it is allowed to access
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCompleteCatalog(self, request, context):
        """Allows a root client to request the full list of files
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Download(self, request, context):
        """Allows a client to request a file from the cloud.
        Download streams a FileResponse until the entire file is downloaded
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FileServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInfo,
                    request_deserializer=v1_dot_file_dot_file__pb2.FileRequest.FromString,
                    response_serializer=v1_dot_file_dot_file__pb2.FileInfo.SerializeToString,
            ),
            'GetCatalog': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCatalog,
                    request_deserializer=v1_dot_file_dot_file__pb2.FileCatalogRequest.FromString,
                    response_serializer=v1_dot_file_dot_file__pb2.FileCatalogResponse.SerializeToString,
            ),
            'GetCompleteCatalog': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCompleteCatalog,
                    request_deserializer=v1_dot_file_dot_file__pb2.FileCompleteCatalogRequest.FromString,
                    response_serializer=v1_dot_file_dot_file__pb2.FileCatalogResponse.SerializeToString,
            ),
            'Download': grpc.unary_stream_rpc_method_handler(
                    servicer.Download,
                    request_deserializer=v1_dot_file_dot_file__pb2.FileRequest.FromString,
                    response_serializer=v1_dot_file_dot_file__pb2.FileResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sensory.api.v1.file.File', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class File(object):
    """Handles all file-related functions
    """

    @staticmethod
    def GetInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.file.File/GetInfo',
            v1_dot_file_dot_file__pb2.FileRequest.SerializeToString,
            v1_dot_file_dot_file__pb2.FileInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCatalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.file.File/GetCatalog',
            v1_dot_file_dot_file__pb2.FileCatalogRequest.SerializeToString,
            v1_dot_file_dot_file__pb2.FileCatalogResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCompleteCatalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.v1.file.File/GetCompleteCatalog',
            v1_dot_file_dot_file__pb2.FileCompleteCatalogRequest.SerializeToString,
            v1_dot_file_dot_file__pb2.FileCatalogResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/sensory.api.v1.file.File/Download',
            v1_dot_file_dot_file__pb2.FileRequest.SerializeToString,
            v1_dot_file_dot_file__pb2.FileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from sensory_cloud.generated.v1.assistant import assistant_pb2 as v1_dot_assistant_dot_assistant__pb2


class AssistantServiceStub(object):
    """Serivce to comunicate with an assistant
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ProcessMessage = channel.stream_stream(
                '/sensory.api.v1.assistant.AssistantService/ProcessMessage',
                request_serializer=v1_dot_assistant_dot_assistant__pb2.AssistantMessageRequest.SerializeToString,
                response_deserializer=v1_dot_assistant_dot_assistant__pb2.AssistantMessageResponse.FromString,
                )


class AssistantServiceServicer(object):
    """Serivce to comunicate with an assistant
    """

    def ProcessMessage(self, request_iterator, context):
        """Sends and process messages from a virtual assistant
        Authorization metadata is required {"authorization": "Bearer <TOKEN>"}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AssistantServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ProcessMessage': grpc.stream_stream_rpc_method_handler(
                    servicer.ProcessMessage,
                    request_deserializer=v1_dot_assistant_dot_assistant__pb2.AssistantMessageRequest.FromString,
                    response_serializer=v1_dot_assistant_dot_assistant__pb2.AssistantMessageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sensory.api.v1.assistant.AssistantService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AssistantService(object):
    """Serivce to comunicate with an assistant
    """

    @staticmethod
    def ProcessMessage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(request_iterator, target, '/sensory.api.v1.assistant.AssistantService/ProcessMessage',
            v1_dot_assistant_dot_assistant__pb2.AssistantMessageRequest.SerializeToString,
            v1_dot_assistant_dot_assistant__pb2.AssistantMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import grpc
from enum import Enum


class EnrollmentType(Enum):
    none = 1
    shared_secret = 2
    jwt = 3


class SDKConfig:
    """
    All configurations required to initialize the Sensory Cloud SDK
    """

    def __init__(
        self,
        fully_qualified_domain_name: str,
        tenant_id: str,
        is_connection_secure: bool,
        enrollment_type: EnrollmentType,
        credential: str,
        device_id: str,
        device_name: str,
    ):

        self.fully_qualified_domain_name = fully_qualified_domain_name
        self.tenant_id = tenant_id
        self.is_connection_secure = is_connection_secure
        self.enrollment_type = enrollment_type
        self.credential = credential
        self.device_id = device_id
        self.device_name = device_name


class CloudHost:
    """
    Class for providing info on a cloud host
    """

    def __init__(
        self,
        host: str,
        port: int = 443,
        is_connection_secure: bool = True,
    ):

        host_split = host.split(":")
        if len(host_split) > 1:
            host = host_split[0]
            port = int(host_split[1])

        self.host = host
        self.port = port
        self.is_connection_secure = is_connection_secure


class Config:
    """
    Configuration class used to establish a channel with the sensory cloud server
    """

    def __init__(
        self,
        tenant_id: str,
        cloud_host: CloudHost,
    ):
        """
        Constructor method for the Config class

        Arguments:
            tenant_id: String containing the tenant to connect to
            cloud_host: CloudHost object that defines the fqdm and whether or not the
                connection is secure
        """

        self.tenant_id = tenant_id
        self.cloud_host = cloud_host
        self.fully_qualified_domain_name = f"{cloud_host.host}:{cloud_host.port}"

        self._channel = None

    def connect(self):
        """
        Public method to setup the grpc channel using the parameters that are set in the
        constructor
        """

        if self.cloud_host.is_connection_secure:
            self._channel = grpc.secure_channel(
                target=self.fully_qualified_domain_name,
                credentials=grpc.ssl_channel_credentials(),
            )
        else:
            self._channel = grpc.insecure_channel(
                target=self.fully_qualified_domain_name,
            )

    @property
    def channel(self) -> grpc.Channel:
        """
        Get method that returns the grpc channel attribute

        Returns:
            The grpc channel object set by the parameters specified in the constructor
        """

        if self._channel is None:
            raise ValueError(
                "no connection has been established with Sensory Cloud. did you forget to call connect()?"
            )
        else:
            return self._channel



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from sensory_cloud.generated.common import common_pb2 as common_dot_common__pb2
from sensory_cloud.generated.health import health_pb2 as health_dot_health__pb2


class HealthServiceStub(object):
    """Service for Health function
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetHealth = channel.unary_unary(
                '/sensory.api.health.HealthService/GetHealth',
                request_serializer=health_dot_health__pb2.HealthRequest.SerializeToString,
                response_deserializer=common_dot_common__pb2.ServerHealthResponse.FromString,
                )


class HealthServiceServicer(object):
    """Service for Health function
    """

    def GetHealth(self, request, context):
        """Obtain an Health and Server status information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HealthServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetHealth': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHealth,
                    request_deserializer=health_dot_health__pb2.HealthRequest.FromString,
                    response_serializer=common_dot_common__pb2.ServerHealthResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'sensory.api.health.HealthService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HealthService(object):
    """Service for Health function
    """

    @staticmethod
    def GetHealth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/sensory.api.health.HealthService/GetHealth',
            health_dot_health__pb2.HealthRequest.SerializeToString,
            common_dot_common__pb2.ServerHealthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import typing

from sensory_cloud.config import Config
from sensory_cloud.token_manager import ITokenManager, Metadata

import sensory_cloud.generated.v1.management.enrollment_pb2_grpc as enrollment_pb2_grpc
import sensory_cloud.generated.v1.management.enrollment_pb2 as enrollment_pb2


class ManagementService:
    """
    Class to handle all typical CRUD functions
    """

    def __init__(self, config: Config, token_manager: ITokenManager):
        """
        Constructor method for the ManagementService class

        Arguments:
            config: Config object containing the relevant grpc connection information
            token_manager: ITokenManager object that generates and returns JWT metadata
        """

        self._config = config
        self._token_manager = token_manager
        self._enrollment_client = enrollment_pb2_grpc.EnrollmentServiceStub(
            config.channel
        )

    def get_enrollments(self, user_id: str) -> enrollment_pb2.GetEnrollmentsResponse:
        """
        Method that obtains all of the active enrollments given the user_id

        Arguments:
            user_id: String containing the user id

        Returns:
            A GetEnrollmentsResponse object
        """

        metadata: Metadata = self._token_manager.get_authorization_metadata()
        request: enrollment_pb2.GetEnrollmentsRequest = (
            enrollment_pb2.GetEnrollmentsRequest(userId=user_id)
        )

        return self._enrollment_client.GetEnrollments(
            request=request, metadata=metadata
        )

    def get_enrollment_groups(
        self, user_id: str
    ) -> enrollment_pb2.GetEnrollmentGroupsResponse:
        """
        Method that obtains all of the active enrollment groups registered by this user_id

        Arguments:
            user_id: String containing the user id

        Returns:
            A GetEnrollmentGroupsResponse object
        """

        metadata: Metadata = self._token_manager.get_authorization_metadata()
        request: enrollment_pb2.GetEnrollmentsRequest = (
            enrollment_pb2.GetEnrollmentsRequest(userId=user_id)
        )

        return self._enrollment_client.GetEnrollmentGroups(
            request=request, metadata=metadata
        )

    def create_enrollment_group(
        self,
        user_id: str,
        group_id: str,
        group_name: str,
        description: str,
        model_name: str,
        enrollment_ids: typing.List[str],
    ) -> enrollment_pb2.EnrollmentGroupResponse:
        """
        Method that registers a new enrollment group. Enrollment groups can contain up to 10 enrollments,
        and they enable multiple users to be recognized with the same request.

        Arguments:
            user_id: String containing the user id
            group_id: String containing the enrollment group id
            group_name: String containing the name of the enrollment group
            description: String containing a brief description of this group
            model_name: String containing the exact name of the model tied to this enrollment group
            enrollment_ids: List of enrollment id strings to add to the new enrollment group
        """

        metadata: Metadata = self._token_manager.get_authorization_metadata()
        request: enrollment_pb2.CreateEnrollmentGroupRequest = (
            enrollment_pb2.CreateEnrollmentGroupRequest(
                userId=user_id,
                id=group_id,
                name=group_name,
                description=description,
                modelName=model_name,
                enrollmentIds=enrollment_ids,
            )
        )

        return self._enrollment_client.CreateEnrollmentGroup(
            request=request, metadata=metadata
        )

    def append_enrollment_group(
        self, group_id: str, enrollment_ids: typing.List[str]
    ) -> enrollment_pb2.EnrollmentGroupResponse:
        """
        Method that adds a new enrollment to an enrollment group

        Arguments:
            group_id: String containing the enrollment group id
            enrollment_ids: List of enrollment id strings the enrollmentIds to
                be associated with this group. Max 10.

        Returns:
            An EnrollmentGroupResponse object
        """

        metadata: Metadata = self._token_manager.get_authorization_metadata()
        request: enrollment_pb2.AppendEnrollmentGroupRequest = (
            enrollment_pb2.AppendEnrollmentGroupRequest(groupId=group_id)
        )
        request.enrollmentIds.extend(enrollment_ids)

        return self._enrollment_client.AppendEnrollmentGroup(
            request=request, metadata=metadata
        )

    def delete_enrollment(self, id: str) -> enrollment_pb2.EnrollmentResponse:
        """
        Removes an enrollment from the system

        Arguments:
            id: String containing the enrollment id to be removed

        Returns:
            An EnrollmentResponse object
        """

        metadata: Metadata = self._token_manager.get_authorization_metadata()
        request: enrollment_pb2.DeleteEnrollmentRequest = (
            enrollment_pb2.DeleteEnrollmentRequest(id=id)
        )

        return self._enrollment_client.DeleteEnrollment(
            request=request, metadata=metadata
        )

    def delete_enrollment_group(
        self, group_id: str
    ) -> enrollment_pb2.EnrollmentGroupResponse:
        """
        Method that removes an enrollment group from the system

        Arguments:
            group_id: String containing the enrollment group to be removed

        Returns:
            An EnrollmentGroupResponse object
        """

        metadata: Metadata = self._token_manager.get_authorization_metadata()
        request: enrollment_pb2.DeleteEnrollmentGroupRequest = (
            enrollment_pb2.DeleteEnrollmentGroupRequest(id=group_id)
        )

        return self._enrollment_client.DeleteEnrollmentGroup(
            request=request, metadata=metadata
        )
